<?

$project_news = array(
array("May 9, 2008",
    "The <a href=http://boincfaq.mundayweb.com/>BOINC FAQ Service</a>
    is now available in Spanish and French
    (as well as English, German, and Dutch)."
),
array("May 7, 2008",
    "<a href=http://www.predictioncenter.org/casp8/index.cgi>CASP8</a>,
    a competition for protein structure prediction, starts soon.
    <a href=http://www.rechenkraft.net>Rechenkraft.net</a> is
    sponsoring a team credit-race to support
    <a href=http://boinc.fzk.de/poem>POEM@home</a>,
    one of the CASP participants.
    Results will be reported at
    <a href=http://starmageddon.dyndns.org/pboinc/index.php>Planet BOINC</a>."
),
array("May 6, 2008",
    "Alpha testing of BOINC software is done by volunteers.
    Many thanks to <a href=http://isaac.ssl.berkeley.edu/alpha/top_testers.php>this month's top testers</a>."
),
array("May 5, 2008",
    "Version 3.0 of <a href=http://www.conmunix.net/offene-projekte/boinc-lcs/>Boinc LCS</a> (a free PHP script for monitoring remote BOINC clients) has been released."
),
array("Apr 20, 2008",
    "The BOINC user documentation has been moved from
    <a href=trac/wiki/RunningBoinc>Trac</a>
    to <a href=wiki/User_manual>Mediawiki</a>,
    which provides better navigation and editing interfaces.
    Please help us fix the remaining broken links."
),
array("Apr 7, 2008",
    "Congratulations to <a href=http://boinc.netsoft-online.com/e107_plugins/boinc/get_user.php?cpid=0c6075252a929a1c9e1a887d1cd85ac5&html=1>NEZ</a>,
    whose contribution to BOINC-based projects recently exceeded 10 TeraFLOPS.
    This would (and should) rank 136th on the
    <a href=http://www.top500.org/>Top 500 Supercomputer</a> list."
),
array("Mar 31, 2008",
    "The BOINC client software is now available for Fedora 7 and higher
    from official repositories.
    To install it, just type <code>yum install boinc-client boinc-manager</code> as root.
    Thanks to Milos Jakubicek, with help from Eric Myers and Debarshi Ray."
),
array("Mar 28, 2008",
    "Read about a new BOINC-based project,
    <a href=http://qcn.stanford.edu/>Quake Catcher Network</a>,
    in
    <a href=http://www.wired.com/science/planetearth/news/2008/03/quake_network>Wired</a> and
    <a href=http://www.nature.com/news/2008/080326/full/452397a.html>Nature News</a>."
),
array("Mar 20, 2008",
    "Watch an excellent talk by CERN's Francois Grey,
    <a href=http://www.liftconference.com/distributed-computing-distributed-thinking>From distributed computing to distributed thinking</a>."
),
array("Mar 5, 2008",
    "Read <a href=http://www.linuxinsider.com/story/Volunteer-Computing-and-the-Search-for-Big-Answers-61943.html>Volunteer Computing and the Search for Big Answers</a>, an article about BOINC and volunteer computing  on LinuxInsider.com."
),
array("Feb 27, 2008",
    "Scientific progress goes BOINC!  Read about the
    <a href=http://boinc.berkeley.edu/trac/wiki/ProjectPapers>Scientific
    publications of BOINC-based projects</a>."
),
array("Feb 12, 2008",
    "Where is BOINC headed?  Marcin Cieslak's vision:
    <a href=http://boinc.berkeley.edu/cieslak.pdf>BOINC on JXTA</a>."
),
array("Feb 11, 2008",
    "Bulgarian BOINC users:
    find forums and information in your language at
    <a href=http://www.boinc-bulgaria.net>BOINC Bulgaria</a>."
),
array("Feb 7, 2008",
    "<a href=http://biology.polytechnique.fr/proteinsathome>Proteins@Home</a>
    has resumed operations.
    Check out their <a href=http://www3.interscience.wiley.com/cgi-bin/abstract/117860966/ABSTRACT?CRETRY=1&SRETRY=0>paper on computational protein design</a>
    in the Journal of Computational Chemistry."
),
array("Jan 31, 2008",
    "The <a href=http://bob.myisland.as/tsp/>TSP project</a>
    is featured in International Science Grid This Week: <a href=http://www.isgtw.org/?pid=1000844>Traveling salesman meets distributed computing</a>."
),
array("Jan 31, 2008",
    "BOINC has broken the PetaFLOP barrier!
    According to <a href=http://boincstats.com/>BOINCStats</a>,
    106 million units of credit were granted yesterday,
    which translates to 1.06 PetaFLOP/sec.
    Congratulations to all projects and participants."
),
array("Jan 24, 2008",
    "A paper describing results of the <a href=http://qah.uni-muenster.de/>Quantum Monte Carlo at Home</a> project recently appeared in the
    <a href=http://pubs.acs.org/cgi-bin/abstract.cgi/jpcafh/asap/abs/jp077592t.html>Journal of Physical Chemistry A (JPCA)</a>."
),
array("Jan 15, 2008",
    "A new article from the <a href=http://www.planetary.org>Planetary Society</a>: 
    <a href=http://www.planetary.org/programs/projects/setiathome/setiathome_20080115.html>From SETI@home to Hominid Fossils: Citizen Cyberscience Reshapes Research Landscape</a>."
),

array("Jan 14, 2008",
    "The cross-project statistics site
    <a href=http://www.allprojectstats.com/>All Project Stats.com</a>
    has many improvements and new features,
    include <a href=http://www.allprojectstats.com/signature.php>credit-based signature images</a> for users and teams."
),
array("Jan 10, 2008",
    "A new competition for BOINC teams,
    <a href=http://www.myboinc.com/FormulaBoinc/>Formula BOINC</a>,
    is based on their position with projects (as in Formula 1 racing)
    rather than overall credit.
    This rewards teams that are diversified across many projects."
),
array("Dec 26, 2007",
    "A story in the Chicago Tribune, \"<a href=http://www.chicagotribune.com/services/newspaper/printedition/tuesday/chi-computer_25dec25,0,2528641.story>Bit by bit, home computers aid science</a>\",
    highlights <a href=http://www.cosmologyathome.org/>Cosmology@home</a>."
),
array("Dec 18, 2007",
    "<a href=http://boinc.umiacs.umd.edu/>The Lattice Project</a>,
    based at the University of Maryland
    Center for Bioinformatics and Computational Biology,
    is now open to volunteers.
    Lattice runs several applications, and supplies computing power to
    a number of Life Sciences researchers.
    Current areas of study include
    evolutionary relationships based on DNA sequence data;
    bacterial, plasmid, and virus protein sequences;
    and biological diversity in nature reserves. "
),

array("Dec 5, 2007",
    "Watch a <a href=http://www.youtube.com/watch?v=GzATbET3g54>YouTube video</a> about the science behind <a href=http://boinc.bakerlab.org/rosetta/>Rosetta@home</a>."
),
array("Dec 5, 2007",
    "The <a href=http://bob.myisland.as/tsp/>TSP</a>
    (Traveling Salesman Problem) project is using BOINC to
    find the shortest path between the capitals of the lower 48 states."
),
array("Dec 3, 2007",
    "This web site, and the BOINC-Wide Teams site,
    will be down for about 18 hours starting at 3 PM PST, Dec 6."
),
array("November 28, 2007",
    "Live in Washington DC?  Get together with other BOINC users via
    <a href=http://opensource.meetup.com/84/?gj=sj2>Meetup</a>
    (or <a href=http://opensource.meetup.com/>create a Meetup
     in your own city</a>)."
),
array("November 16, 2007",
    "<a href=http://boinc.gorlaeus.net/>Leiden Classical</a> allows students (and the public)
    to submit particle-system simulation jobs,
    and is thus a resource for both education and research.
    The job-submission system used by Leiden Classical is now
    <a href=http://boinc.berkeley.edu/trac/wiki/UserJobs>included in the BOINC source code distribution</a>."
),
array("November 2, 2007",
    "BOINC needs more volunteer programmers!
    If you're proficient in PHP and MySQL, C++ and WxWidgets,
    or C++ system programming,
    please <a href=http://boinc.berkeley.edu/trac/wiki/DevProjects>read
    about how you can help</a>."
),
array("October 22, 2007",
    "The BOINC-based <a href=http://www.bbc.co.uk/sn/climateexperiment>BBC
    Climate Change Experiment</a> has won the prestigious
    <a href=http://www.prix-europa.de/>Prix Europa</a>
    award in the Internet category."
),
array("October 21, 2007",
    'Conmunix has released version 3.0 beta of
    <a href=http://www.conmunix.net/boinc-lcs>Boinc LCS</a>
    (Live Client State), a PHP script that allows you to monitor
    the current state and other information from each of
    your BOINC clients.'
),
array("October 18, 2007",
    "BOINC user John Koulouris has written <a href=http://www.angelfire.com/jkoulouris-boinc/>The Big BOINC! Projects and Chronology Page</a>,
    a brief history of BOINC."
),
array("October 17, 2007",
    "Congratulations to the <a href=http://www.ukboincteam.org.uk/>UK BOINC Team</a>,
    which today became the first UK-specific team to
    pass the 100 million combined credits mark."
),
array("October 17, 2007",
    "An article in Nature,
    <a href=http://www.nature.com/news/2007/071016/full/449765a.html>The shape of protein structures to come</a>, discusses the goals and progress of the
    <a href= http://boinc.bakerlab.org/rosetta/>Rosetta@home</a> project from the University of Washington."
),
array("October 12, 2007",
    "LHC@home has moved from CERN to the University of London.
    Read about it <a href=http://www.interactions.org/cms/?pid=1025457>here</a>."
),
array("October 4, 2007",
    "The National Science Foundation has awarded a three-year grant,
    NSF award #OCI-0721124, to the BOINC project.
    This will support our development efforts through August 2010."
),
array("September 26, 2007",
    "The Third Pan-Galactic BOINC Workshop took place 5-6 Sept. in Geneva.
    The proceedings, including talk slides and notes from
    the breakout sessions, are
    <a href=http://boinc.berkeley/edu/trac/wiki/WorkShop07/Summary>here</a>."
),
array("September 25, 2007",
    "Check out the <a href=http://boinc.iaik.tugraz.at/>SHA-1 Collision Search Graz</a>
    project, which is based at the Graz University of Technology
    and does research in cryptography."
),
array("September 24, 2007",
    "Team founders: you can now make your team
    <a href=teams/>BOINC-wide</a>,
    meaning that it will be created on all
    current and future BOINC projects."
),
array("September 24, 2007",
    "A one-day session on BOINC will be presented at the
    <a href=http://acgrid.in2p3.fr>Advanced Computing and GRID technologies for Research</a> school in Hanoi, November 5-16, 2007."
),
array("September 21, 2007",
    "A <a href=http://boinc.berkeley.edu/boinc_papers/client_sch_eval/client_sch_eval.pdf>paper about scheduling in BOINC</a>
    will appear in the 3rd IEEE International Conference on e-Science and Grid Computing. Banagalore, India, December 10-13 2007."
),
array("September 7, 2007",
    "The new BOINC logo is now available in
    <a href=logo.php>a variety of formats and resolutions.</a>"
),
array("August 17, 2007",
    "World Community Grid has announced that it is
    <a href=http://www.worldcommunitygrid.org/forums/wcg/viewthread?thread=15715 >migrating fully to BOINC</a>.
    Welcome to all WCG participants!"
),
array("July 25, 2007",
    "BOINC finally has a new logo!
    Many thanks Michal Krakowiak, the graphic designer who created it.
    The logo (and icons based on it)
    will soon appear on the BOINC client software
    as well as the web site."
),
array("July 23, 2007",
    "<a href=images/africa_workshop_7_07.jpg><img align=right src=images/workshop_200.jpg></a>
    The Africa@home workshop on volunteer computing with BOINC,
    sponsored by the Geneva International Academic Network (GIAN),
    was held recently at the African Institute for Mathematical Sciences in Muizenberg, South Africa.
    <br clear=all>"
),
array("July 20, 2007",
    "A newly-launched project, <a href=http://eternity2.net/>Eternity2.net</a>,
    offers a chance to compute for a share of a US$2,000,000 prize."
),
array("July 20, 2007",
    "Team leaders: check out the
    <a href=http://www.boincteams.com/>BOINC Team Leaders Forum</a>,
    a place to chat and discuss team-building on BOINC projects."
),
array("July 16, 2007",
    "If you use the Yahoo! Widget Engine,
    check out version 1.1 of the <a href=http://boinc.berkeley.edu/addon_item.php?platform=browser&item=BOINC_server_status.zip>BOINC Server Status</a> widget."
),
array("July 16, 2007",
    "BOINC is now the preferred client software at
    <a href=http://worldcommunitygrid.org>World Community Grid</a>."
),
array("July 12, 2007",
    "<a href=http://boinc.gorlaeus.net/>Leiden Classical</a>
    is using BOINC for education - it provides a
    <a href=http://boinc.gorlaeus.net/ClassicalBuilder.php>
    high-performance computing resource</a> for
    students of Theoretical Chemistry at Leiden University."
),
array("July 10, 2007",
    "<a href=http://boinc.berkeley.edu/images/gw.jpg border=0><img align=right src=http://boinc.berkeley.edu/images/gw_small.jpg></a>
    A growing number of 'skins' for the BOINC simple GUI are available
    from <a href=http://crunching-family.at/dlc/>crunching-family.at</a>.
    Here's an example.
    "
),
array("July 6, 2007",
     "Welcome to a new web site with cross-project BOINC statistics:
     <a href=http://statsnstones.tswb.org/>Team Starfire World BOINC Stats 'N Stones</a>."
),
array("July 5, 2007",
    "Windows users:
    <a href=http://www.nuchill.de/nboinc/>version 2.0 of nBOiNC</a>,
    an add-on application for viewing your up-to-the-minute credit totals,
    has been released."
),
array("July 4, 2007",
    "Docking@home is moving from Texas to Delaware. Volunteers should detach from the project; you will be emailed when the project is alive in Delaware."
),
array("July 2, 2007",
    "Read <a href=http://www.isgtw.org/?pid=1000527>Volunteer computing: Grid or not Grid?</a> on International Science Grid This Week."
),
array("July 2, 2007",
    "Amir Alexander of The Planetary Society talks about
    <a href=http://www.boincuk.com/amir_alexander.mp3>SETI, distributed computing, and space exploration</a> in an interview by Mike of BOINC UK."
),
array("June 28, 2007",
    "Linux users: if you use bash,
    check out a cool <a href=http://boinc.berkeley.edu/trac/wiki/BashCommandCompletion>script</a>
    that provides command completion in both boinc_cmd and boinc_client
    (thanks to Frank S. Thomas)."
),
array("June 27, 2007",
    "Help increase volunteer computing power -
    <a href=http://boinc.berkeley.edu/trac/wiki/BoincPr>publicize BOINC</a> by writing to computer magazines."
),
array("June 26, 2007",
    "There's a great new statistics site,
    <a href=http://www.allprojectstats.com/>BOINC All Project Stats</a>.
    It has lists of the top users and teams,
    recent changes in rankings, graphs showing history and
    breakdown by project, and many other features.
    You can also see the stats and rankings
    of an individual volunteer or team across all BOINC projects.
    Thanks to Markus Tervooren for putting this together!"
),
array("June 26, 2007",
    "There are reports that version 5.10.8 of the BOINC client software
    causes a problem on Windows XP Pro in which the desktop becomes empty.
    If you see this, please uninstall 5.10.8 and install version 5.8.16."
),
array("June 3, 2007",
    "BOINCstats and BAM! are now viewable in Finnish
    (<a href=http://fi.boincstats.com>http://fi.boincstats.com</a>). "
),
array("May 31, 2007",
    "Sony Playstation 3 owners: researchers at the Barcelona
    Biomedical Research Park have launched
    <a href=http://www.ps3grid.net/>PS3GRID</a>,
    a BOINC-based project whose application
    (molecular dynamics simulations) runs on the
    PS3's Cell processor, on Linux."
),
array("May 29, 2007",
    "Check out <a href=http://www.youtube.com/watch?v=UNDcMAePKYY&eurl=http%3A%2F%2Fcb%2Dtools%2Epytalhost%2Ede%2Fblog%2F>a video promoting BOINC</a> on YouTube.</a>"
),
array("May 28, 2007",
    "A <a href=http://www.kd-web.info/boinc_tutorial_wcg-english.php>Flash guide to using BOINC with IBM World Community Grid</a> is available in Czech and English."
),
array("May 14, 2007",
    "The <a href=http://boinc.berkeley.edu/trac/wiki/WorkShop07>3rd Pan-Galactic
    BOINC Workshop</a> will be held 5-6 September 2007 in Geneva, Switzerland."
),
array("May 9, 2007",
    "The BOINC Virtual Server - a VMWare virtual machine
    preconfigured with BOINC and all prerequisite software -
    is <a href=http://boinc.berkeley.edu/trac/wiki/ServerIntro>now available</a>.
    This greatly simplifies the task of creating a BOINC projects.
    Thanks to Christian Beer for creating this."
),
array("May 8, 2007",
    "As of about May 1, BOINC projects have had
    <a href=http://boinc.berkeley.edu/dev/forum_thread.php?id=1777>over one million volunteers</a>."
),
array("May 6, 2007",
    "An excellent article on BOINC and the projects using it
    appeared today in the Catalan newspaper AVUI.
    It is available in PDF (pages
    <a href=http://media.avui.cat/pdf/07/0506/070506diari034.pdf>one</a>
    and <a href=http://media.avui.cat/pdf/07/0506/070506diari035.pdf>two</a>)
    and also as a <a href=http://paper.avui.cat/article/societat/73609/computacio/ciutadana.html>web page</a>.
    Thanks to Dr. Jordi Portell i de Mora for telling us about it."
),
array("May 6, 2007",
    "<a href=http://www.boincstats.com/>BOINCstats and BAM!</a>
    are now available in 15 languages.
    As of today, they are now viewable in Swedish
    (<a href= http://se.boincstats.com> http://se.boincstats.com</a>)."
),
array("May 3, 2007",
    "The source code behind <a href=http://boinc.netsoft-online.com/>BOINC Combined Stats</a> is now <a href=trac/wiki/CreditStats#Codeexamples>available via Subversion</a>.  This may be helpful for other statistics site developers."
),
array("April 24, 2007",
    "<a href=http://www.gridrepublic.org/>GridRepublic</a> announces
    a significant upgrade to their web site, including improved
    registration workflow and better integration with IBM World Community Grid
    (including WCG sub-project registration)."
),
array("April 23, 2007",
    "Krystof Dolezal's
    <a href=http://www.kd-web.info/clanky.php>Flash-based BOINC tutorials</a>
    are now available in English and Slovak,
    as well as Czech."
),
array("April 23, 2007",
    "BOINCstats and BAM! are now available in the Czech language
    (<a href=http://cz.boincstats.com>http://cz.boincstats.com</a>).
    Thanks to Zelvuska for the translation."
),
array("April 17, 2007",
    "<a href=http://desktopgrid.hu/>Desktopgrid.hu</a>
    has been created by the Computer and Automation Research Institute
    (SZATAKI) of the Hungarian Academy of Sciences (MTA).
    It provides information (and software downloads) for using
    BOINC for <a href=dg.php>desktop Grid computing</a>."
),
array("April 16, 2007",
    "BOINC is now using <a href=http://trac.edgewall.org/>Trac</a>,
    an integrated software project management system.
    In particular:
    1) the BOINC source code repository now uses Subversion;
    2) the BOINC bug database has been moved to Trac;
    3) documentation will be moved to a Wiki.
    See <a href=trac/>the BOINC/Trac page</a>.
    "
),
array("April 11, 2007",
    "The BBC documentary 'Meltdown',
    which highlights <a href=http://climateprediction.net>Climateprediction.net</a>,
    has been nominated for
    a <a href=http://www.bafta.org/site/page129.html>British Academy of
    Film and Television Arts</a> academy award."
),
array("April 4, 2007",
    "Dr. Anderson gave the keynote talk,
    <a href=talks/ipdps_07_kn.ppt>Volunteer Computing: Planting the Flag</a>,
    at the PCGrid 2007 workshop,
    held at the IPDPS conference in Long Beach on March 30."
),
array("March 29, 2007",
    "If you can read Czech, czech out some excellent
    <a href=http://www.kd-web.info/clanky.php>Flash-based BOINC tutorials</a>."
),
array("March 23, 2007",
    "Africa@home (with support from the
    Geneva International Academic Network)
    is sponsoring an
    <a href=images/africa_at_home_workshop.pdf>intensive one-week workshop on volunteer computing</a>
    for qualified African students,
    to be held at the African Institute for Mathematical Sciences
    in Muizenberg, South Africa, 16-22 July 2007."
),
array("March 9, 2007",
    "<img align=right src=images/stamps/stamp-rosetta.png>
    Don't use them for postage, but check out the
    <a href=images/stamps>BOINC stamps</a>
    created by Myster65 and Rebirther."
),
array("March 6, 2007",
    "The article <a href=http://www.linux-magazine.com/issue/71/Distributed_Applications_With_BOINC.pdf>Idle Cycles - building distributed applications with BOINC</a> Seil appears in the Oct 2006 issue of
<a href=http://www.linux-magazine.com/issue/71>Linux Magazine</a>.
In it, author Marc Seil
provides a detailed description of how to set up a BOINC project."
),
array("March 1, 2007",
    "With <a href=http://boincpe.schreiter.info/>BOINCpe</a>
    you can run a dedicated BOINC machine using a RAM disk,
    starting from only 256 MB of total RAM.
    This lets you operate a BOINC farm more energy-efficiently
    or to use machines without hard disk drives for BOINC."
),
array("February 28, 2007",
    "The BOINC web server recently underwent a
    hardware and software upgrade. Certain projects and
    pages may still be offline as we continue to configure
    the new system."
),
array("February 8, 2007",
    "Marc Seil gave a talk on setting up a BOINC server
    at the recent <a href=http://www.linuxdays.lu>LinuxDays</a>
    conference in Luxembourg.
    His slides are <a href=contrib/boinc_v1.3.pdf>here</a>."
),
array("February 5, 2007",
    "<a href=http://gridrepublic.org>GridRepublic</a>
    has been selected as a finalist for the Web Awards
    at the 2007 SXSW Interactive Festival. Please
    <a href=https://secure.sxsw.com/peoples_choice/>click here</a>
    to cast your vote for them at the SXSW website.
    "
),
array("February 3, 2007",
    "The documentation on Creating BOINC Projects is now available as 
    <a href=http://boinc.berkeley.edu/boinc.pdf>one big PDF file</a>."
),
array("January 24, 2007",
    "The <a href=http://boincfaq.mundayweb.com/>BOINC FAQ Service</a>
    answers many questions about using BOINC.
    It is available in English, German, and Dutch."
),
array("January 19, 2007",
    "Check out a
    <a href=http://youtube.com/watch?v=kCYlZ8-l5jc>TV news segment</a>
    and a <a href=http://www.bbc.co.uk/sn/climateexperiment/>web site</a>
    about the results of the recently-completed
    BBC Climate Change Experiment.
    On January 21 BBC aired a documentary on the results of this project;
    an excerpt is <a href=http://www.youtube.com/watch?v=mNud-goRBgE>here</a>."

),
array("January 18, 2007",
    "The paper \"<a href=http://research.microsoft.com/research/pubs/view.aspx?type=Technical%20Report&id=1259>Reporting@Home: Delivering Dynamic Graphical Feedback to Participants in Community Computing Projects</a>\"
    describes how Rosetta@home delivers personalized
    graphical progress reports to its volunteers."
),
array("January 17, 2007",
    "Linux users: check out
    <a href=http://kde-apps.org/content/show.php?content=44237>KBoincMgr</a>,
    a replacement for the BOINC Manager.
    KBoincMgr can manage multiple BOINC clients,
    and has other features too numerous to mention."
),
array("January 17, 2007",
    "On Sunday 21 Jan. at 8pm BBC 1 will broadcast
    <a href=http://www.bbc.co.uk/bbcone/listings/programme.shtml?day=sunday&service_id=4223&filename=20070121/20070121_2000_4223_18875_60>Climate Change: Britain Under Threat</a>.
    This will include results from the BBC and CPDN experiments,
    and an interview with CPDN staff.
    In addition, results should appear on the <a href=http://www.bbc.co.uk/sn/hottopics/climatechange/>BBC Climate Change website</a>."
),
array("January 7, 2007",
    "The <a href=http://abcathome.com>ABC@home</a> project,
    based at <a href=http://www.math.leidenuniv.nl/>Leiden University</a>
    in Holland, is now open.
    ABC@home is studying the <a href=http://en.wikipedia.org/wiki/Abc_conjecture>ABC conjecture</a>,
    a major open problem in mathematics."
),
array("January 6, 2007",
    "MySpace users: check out the
    <a href=http://groups.myspace.com/BOINConMYSPACE>BOINC on MySpace</a> group."
),
array("December 29, 2006",
    "A <a href=http://boinc.berkeley.edu/boinc_papers/sched/paper.pdf>paper about BOINC client scheduling</a> will appear in the
    Workshop on Large-Scale, Volatile Desktop Grids held in conjunction with the IEEE International Parallel & Distributed Processing Symposium (IPDPS), March 30, 2007, Long Beach."
),
array("December 28, 2006",
    "The <a href=http://biology.polytechnique.fr/proteinsathome>Proteins@Home</a> project is now open.
    Proteins@Home is a large-scale protein structure prediction project,
    and is based at the &Eacute;cole Polytechnique in Paris."
),
array("December 21, 2006",
    "Some AOL users are unable to attach to some projects.
    A work-around for this problem is described
    <a href=http://boinc.berkeley.edu/aol.php>here</a>."
),
array("December 8, 2006",
    "<a href=http://boinc.berkeley.edu/skins.php><img align=right src=images/boinccast_small.png></a>
    Olaf Bornack of
    <a href=http://www.boinc-halle-saale.de/>Team BOINC@Halle/Saale</a>
    has supplied
    <a href=http://boinc.berkeley.edu/http://boinc.berkeley.edu/trac/wiki/ManagerSkin#stencils>stencils</a>
    for creating skins for the new BOINC GUI.
    These have been used to make skins with
    <a href=http://boinc.berkeley.edu/http://boinc.berkeley.edu/trac/wiki/SkinExamples>BOINCcast,
    BOINC@Halle/Saale, and BOINCmas!</a> themes.
    <br clear=all>
    "
),
array("December 6, 2006",
    "Linux users: check out the new
    <a href=http://www.vanheusden.com/boinctail/>BOINCTail</a> add-on."
),
array("December 4, 2006",
    "BOINC's new <a href=http://boinc.berkeley.edu/help.php>Online Help system</a>
    lets you get help from volunteers
    by talking with them using <a href=http://www.skype.com>Skype</a>.
    Volunteers speak several languages."
),
array("December 4, 2006",
    "It hasn't been released yet,
    but already several skins are available for BOINC Manager version 5.8
    (currently under test as version 5.7.x).
    Check out <a href=http://www.crunching-family.at/download-center/>Crunching Family Skin Downloads</a>."
),
array("December 4, 2006",
    "A recent article in the Bulletin of the Howard Hughes Medical Institute,
    <a href=http://www.hhmi.org/bulletin/nov2006/pdf/Cast.pdf>A Cast of Thousands<a/>, discusses the
    <a href=http://boinc.bakerlab.org/rosetta/>Rosetta@home</a> project
    and its army of dedicated volunteers."
),
array("November 27, 2006",
    "Jean-Michel Penasse of L'Alliance Francophone
    has create a web site,
    <a href=http://www.myboinc.com/>www.myboinc.com</a>,
    showing the User of the Day of all BOINC projects
    going back to October 8 2006.  Check it out!"
),
array("November 23, 2006",
    "<b>Docking@home participants</b>:
    the project is unreachable because of a campus-wide network
    connection failure at Univ. of Texas - El Paso.
    Please check back periodically."
),
array("November 15, 2006",
    "BOINCstats is now available in Spanish.
    Thanks to Miquel Pericas for the translation.
    BOINCstats in Spanish can be visited at
    <a href=http://es.boincstats.com>http://es.boincstats.com</a>."
),
array("November 7, 2006",
    "Check out new add-on software:
    the <a href=http://boinc.berkeley.edu/addon_item.php?platform=browser&item=http%3A%2F%2Fsetihometoolbar.ourtoolbar.com%2F>SETI@home Toolbar</a>
    for Firefox and IE on Windows (SETI@home-specific), and
    <a href=http://www.helsinki.fi/~earajarv/programs/boinctray/>Boinctray</a>,
    a system tray application for Linux."
),
array("November 7, 2006",
    "We are preparing to release client software with
    a new GUI that is simpler, smaller, and more graphical
    than the current BOINC manager.
    Projects can supply their own graphics
    (icons, application-specific slideshows) for use in this GUI;
    see <a href=http://boinc.berkeley.edu/ProjectSkin>instructions for how to do this</a>.
    In addition, the GUI itself is skinnable;
    a skin consists of
    <a href=http://boinc.berkeley.edu/trac/wiki/ManagerSkin>an XML
    file and a collection of images</a>."
),
array("October 17, 2006",
    "Issue 3 of
    <a href=http://www.boincuk.com/newsLetter/bunc-03.pdf>bunc (BOINC UK newsletter)</a> is now online, with articles on a wide range of topics."
),
array("October 9, 2006",
    "Interested in getting a one-CPU-month job finished in five minutes?
    BOINC can potentially help you do this, but
    <a href=http://boinc.berkeley.edu/trac/wiki/LowLatency>some work is needed</a>."
),
array("October 8, 2006",
    "Versions of BOINC (and some applications) are now
    available for
    Solaris (x86, i686, SPARC),
    Linux (Alpha, SPARC),
    FreeBSD (x86, Alpha) and
    HPUX (including the BOINC Manager) from
    <a href=http://www.lb.shuttle.de/apastron/boincDown.shtml>www.lb.shuttle.de</a>."
),
array("October 4, 2006",
    "Eric Korpela and David Anderson were interviewed today
    by Mike O'Connell of BOINC UK.
    Many topics were covered, including the question of
    credit and optimized clients.
    Download a recording of the conversation (MP3, 13.5 MB) from
    <a href=http://www.boincuk.com/david_anderson.mp3>BOINC UK</a>
    or <a href=mp3/boincuk_4_oct_2006.mp3>a mirror at Berkeley</a>."
),
array("September 26, 2006",
    "The 2nd Annual Pangalactic BOINC Workshop was held
    in Geneva on 20-21 September.
    Read <a href=ws_06.php>the online workshop proceedings</a>."
),
array("September 11, 2006",
    "<a href=chart_list.php>UW-Madison CAE</a>,
    the first BOINC user to top the 1 TERAFLOPS barrier,
    now has surpassed 2 TERAFLOPS.  Congratulations!"
),
array("September 2, 2006",
    "The <a href=http://spin.fh-bielefeld.de/>Spinhenge</a> project
    has moved into public beta test,
    and is accepting new participant accounts."
),
array("August 24, 2006",
    "<a href=http://gridrepublic.org>GridRepublic</a>,
    a BOINC account manager, recently moved into beta test.
    It was written up by <a href=http://news.com.com/2061-12572_3-6108804.html>CNET</a>."
),
array("August 20, 2006",
    "BOINC and SETI@home are featured in
    <a href=http://www.be.asahi.com/20060819/W16/20060803TBEH0006A.html>an
    article in Asahi-shinbun</a>,
    one of the most popular newspapers in Japan."
),
array("August 16, 2006",
    "New documents discuss using BOINC for
    <a href=dg.php>Desktop Grid Computing</a>
    and for creating
    <a href=http://boinc.berkeley.edu/trac/wiki/VirtualCampusSupercomputerCenter>Virtual Campus Supercomputing Centers</a>."
),
array("August 15, 2006",
    "A BBC Radio program on 'Citizen Science' - including
    a segment on volunteer computing and BOINC -
    will air tomorrow, 16 Aug 2006, 9 PM British Time.
    It will also be available 
    <a href=http://www.bbc.co.uk/radio4/science/citizenscience.shtml>online</a>.
    "
),
array("August 14, 2006",
    "Participants with preferences for different venues
    (home, school, work) can now view these side-by-side
    in a multi-column format.
    Also, preference values are now checked for validity.
    Thanks to Christian Beer for the PHP programming behind
    these improvements."
),
array("August 11, 2006",
    "An <a href=http://qah.uni-muenster.de/article1.php>article about
    Quantum Monte Carlo at Home</a> appeared 03.08.2006 in the German newspaper WAZ."
),
array("August 3, 2006",
    "A recent update of McAfee security software on Windows
    causes BOINC 5.4.9 to not work (<a href=mcafee.php>details</a>).
    We have released a new version, 5.4.11,
    that fixes the problem and works with the latest McAfee software."
),
array("August 2, 2006",
    "The <a href=workshop_06.php>2nd Pan-Galactic BOINC Workshop</a>
    will be held 20-21 September at the University of Geneva, Switzerland.
    Anyone actively involved with BOINC is encouraged to attend."
),
array("July 26, 2006",
    "<a href=http://www.chess960athome.org/>Chess960@home</a>
    is open for testers.
    This project studies a game that is like classical chess
    except that the initial configuration of pieces
    is chosen randomly from among 960 possibilities."
),
array("July 25, 2006",
    "Welcome to three new BOINC-based projects.
    Two are mathematical:
    <a href=http://boinc.rieselsieve.com/>Riesel Sieve</a>
    looks for prime numbers of the form k2<sup>n</sup>-1,
    and <a href=http://dist.ist.tugraz.at/cape5/>Rectilinear Crossing Number</a>
    studies a problem in computational geometry.
    The third, <a href=http://spin.fh-bielefeld.de/>Spinhenge@home</a>,
    studies molecular magnets and controlled nanoscale magnetism,
    which may have applications in medicine and biotechnology."
),
array("July 22, 2006",
    "BOINC user survey:
    due to a bug in our software, answers to the question
    'Which are the most important factors when you decide whether to participate in a BOINC project?' were not recorded correctly.
    Please <a href=poll.php>fill out the survey form again</a>.
    We apologize for the inconvenience."
),
array("July 21, 2006",
    "The BOINC survey is now available in
    <a href=http://boinc.oocp.org/poll.php>Japanese</a>.
    If you'd like to translate it to another language,
    please <a href=trac/wiki/ProjectPeople>contact us</a>."
),
array("July 13, 2006",
    "We are conducting an <a href=poll.php>online survey</a>
    of BOINC participants.
    Please fill out the survey form -
    your responses will help us improve BOINC and the projects that use it. "
),
array("July 13, 2006",
    "Articles in
    <a href=http://www.nature.com/news/2006/060717/full/060717-15.html>Nature</a>,
    <a href=http://www.economist.com/science/displayStory.cfm?story_id=7159442>The Economist</a>
    and <a href=http://www.webwire.com/ViewPressRel.asp?aId=16636>WebWire</a>
    describe <a href=http://africa-at-home.web.cern.ch/>Africa@home</a>,
    an initiative that supports African humanitarian causes.
    Their first BOINC-based project,
    <a href=http://www.malariacontrol.net/>malariacontrol.net</a>,
    studies malaria epidemiology.
    Africa@home is a collaboration of the Swiss Tropical Institute,
    CERN, and a group of universities (three of them from Africa).
    "
),
array("July 7, 2006",
    "The <a href=http://issofty17.is.noda.tus.ac.jp/>TANPAKU</a>
    project, based at the Tokyo University of Science,
    is open for participation.
    TANPAKU (from the Japanese word <i>tanpaku-shitsu</i>,
    meaning 'protein') studies protein structure and function
    using a novel method called Brownian Dynamics."
),
array("June 30, 2006",
    "Want to deploy BOINC quickly and easily on a Windows network?
    Read <a href=http://www.thelazyslug.com/boinc.htm>The Lazy Slug's Guide
    to easy deployment and maintenance of BOINC on your network</a>."
),
array("June 29, 2006",
    "<a href=http://boinc.berkeley.edu/boinc_papers/api/text.pdf>A
    paper about BOINC's API and runtime system</a>
    will appear in the <a href=http://sc06.supercomp.org>SC06 conference</a>."
),
array("June 28, 2006",
    "A new <a href=http://boinc.berkeley.edu/trac/wiki/SandboxUser>Secure BOINC Client</a>
    for the Macintosh is available for testing.
    This version limits BOINC applications' access to your system and data,
    thus protecting your computer from accidental or malicious damage
    or data theft."
),
array("June 22, 2006",
    "Pav Lucistnik has developed
    <a href=http://www.oook.cz/bsd/boinc_curses/>boinc_curses</a>,
    a Unix console-based program (like 'top')
    to monitor and control BOINC."
),
array("June 21, 2006",
    "BOINCstats and the BAM! account manager
    are now available <a href=http://jp.boincstats.com>in Japanese</a>."
),
array("June 15, 2006",
    "BOINC's CPU scheduler has become smarter:
    it now waits until an application has checkpointed
    to preempt it and remove it from memory.
    This can save significant CPU time, especially on multiprocessors.
    Technical details are <a href=sched.php>here</a>.
    The new scheduler is in the development version of BOINC,
    and will appear in the 5.6 release.
    Volunteer developer John McLeod VII was the driving
    force behind the new scheduler."
),
array("June 14, 2006",
    "We have added preliminary support for
    <a href=wrapper.php>legacy applications</a>
    that do not use the BOINC API
    (e.g. because their source code is not available).
    This feature will work with the next version
    (5.6) of the BOINC client software.
    "
),
array("June 10, 2006",
    "The <a href=http://www.boincuk.com/newsletter_reg.php>BOINC UK Newsletter Circular</a> (bunc) has released its June 2006 edition,
    featuring an interview with David Anderson."
),
array("June 7, 2006",
    "Windows users: if BOINC applications are repeatedly
    crashing on your computer,
    it's possibly that you need to
    <a href=directx.php>upgrade to the latest version of DirectX</a>."
),
array("May 31, 2006",
    "Recent newspaper articles on BOINC and Rosetta@home:
    <a href=http://seattletimes.nwsource.com/html/localnews/2003027071_computersider30m.html>Worldwide, 690,000 help computer effort</a> and
    <a href=http://seattlepi.nwsource.com/local/6420AP_WA_Research_at_Home.html>Medical researcher taps the power of home computing</a>."
),
array("May 30, 2006",
    "The <a href=http://bam.boincstats.com>BOINCStats Account Manager</a>
    (BAM!) is now available for use.
    BAM! provides 'one-stop shopping' for finding
    and attaching to BOINC project;
    see the news item of May 11.
    Thanks to Willy de Zutter for developing BAM!."
),
array("May 25, 2006",
    "BOINC has added preliminary support for 'low-latency' computing;
    e.g. delay bounds of minutes rather than days.
    This requires having clients contact the server frequently;
    we've added a mechanism that lets the server specify
    the connection interval.
    This will be available in the next release (5.6) of the client software.
    Projects that are interested in using this mechanism should
    <a href=contact.php>contact us</a>."
),
array("May 17, 2006",
    "The costs of electricity, both monetary and environmental, are high.
    Be aware of the <a href=energy.php>energy considerations</a>
    associated with BOINC and volunteer computing."
),
array("May 11, 2006",
    "Version 5.4 of the BOINC client software has been released.
    This version lets you use <a href=trac/wiki/AccountManagers>account managers</a> -
    special web sites that let you browse BOINC projects,
    attach/detach, change resource share and settings,
    all with point-and-click simplicity.
    Account managers are also great if you have several computers -
    you make changes on the web site,
    and they take effect on all of your computers.
    A couple of excellent account managers are nearly ready for use;
    stay tuned for details."
),
array("May 9, 2006",
    "The first-ever
    <a href=http://www.seti.cat/web/?q=node/18>BOINC birthday cake</a>
    appeared at the 7th SETI@home-Catalonia Meeting
    (and 1st BOINC-Catalonia Meeting), held in Girona last April 22nd.
    Also: <a href=http://www.boinc.cat>BOINC.cat</a>,
    a BOINC site in Catalan, has recently opened.
"),
array("April 30, 2006",
    "<img align=right width=75 height=66 src=images/Logo_blau.jpg> The latest German <a href=http://boinccast.podhost.de/>BOINCcast</a>
    discusses ClimatePrediction.net;
    earlier BOINCcasts cover SIMAP, LHC@home, and uFluids.
    <br>
    "
),
array("April 14, 2006",
    "The CERN Courier's Computer Newsletter features an article on
    <a href=http://www.cerncourier.com/articles/cnl/3/4/14/1>BOINC activities at CERN</a>.
"),
array("April 13, 2006",
    "According to various <a href=links.php>statistics sites</a>,
    over one million computers have now contributed
    processing power to BOINC projects.
    We're currently achieving a sustained processing rate
    of over 400 TeraFLOPS - the world's most powerful supercomputer
    by a wide margin.
    Congratulations and thanks to everyone!
"),
array("April 13, 2006",
    "We have developed an <a href=example.php>example application</a>,
    together with project files and Makefiles for Windows, Mac, and Linux.
    The application demonstrates how to do checkpoint/restart and graphics.
    Projects can use this as a framework for building their own applications.
"),
array("April 6, 2006",
    "Thanks to the efforts of
    <a href=http://alioth.debian.org/projects/pkg-boinc/>volunteers</a>,
    BOINC is now officially part of the Debian Linux distribution.
    Packages for the BOINC
    <a href=http://packages.debian.org/boinc-client>core client</a>
    and <a href=http://packages.debian.org/boinc-manager>Manager</a>
    are available for 13 different platforms
    (alpha, amd64, arm, hppa, 
    i386, ia64, kfreebsd-i386, m68k, mips, mipsel, powerpc, s390 and sparc).
"),
array("April 4, 2006",
    "Windows users: new versions of
    <a href=http://www.microsoft.com/hardware/mouseandkeyboard/DownloadResult.aspx?prod=m_wom20&os=xp&lang=en&driverVersion=IntelliPoint%205.5>Intellipoint</a>
    and <a href=http://www.microsoft.com/hardware/mouseandkeyboard/DownloadResult.aspx?prod=m_wNMK&os=xp&lang=en&driverVersion=IntelliType%20Pro%205.5>Intellitype</a>
    are available from Microsoft.
    Upgrading to these may fix problems with the BOINC screensaver.
    "
),
array("April 3, 2006",
    "<a href=http://boincstats.com>BOINCstats.com</a> is one of
    several excellent web sites showing BOINC statistics.
    It's available in a number of languages, now including
    <a href=http://cn.boincstats.com/>Chinese</a>.
    "
),
array("March 15, 2006",
    "The <a href=http://attribution.cpdn.org/>Seasonal Attribution Project</a>,
    a spin-off of Climateprediction.net,
    seeks to determine the extent to which extreme weather events
    are attributable to human-induced climate change.
    Its application is a high-resolution simulation of the world's climate,
    and is recommended only for computers
    with at least 1 GB of RAM, and a 2.4GHz Pentium or faster processor.
    "
),
array("March 5, 2006",
    "Tony/Knightrider/Chuggybus has created BOINC coinage.
    See the <a href=images/coins/>large</a>
    and <a href=images/coins_small>small</a> versions.
    The Latin text means 'Berkeley open and shared resources'.
    "
),
array("March 3, 2006",
    "<a href=http://qah.uni-muenster.de/>Quantum Monte Carlo at Home</a>
    announces the public release of the first chemistry BOINC project.
    This project, based at the University of M&uuml;nster in Germany,
    studies the structure and reactivity of molecules using Quantum Chemistry,
    whose vastly complex equations require huge amounts of computing power.
    "
),
array("February 24, 2006",
    "A significant step has been made towards integrating
    BOINC and Grid software:
    beginning with Condor version 6.7.17,
    Condor can be configured to run BOINC when it has no other work to perform.
    This capability is described in <a href=http://www.cs.wisc.edu/condor/manual/v6.7/3_13Setting_Up.html#SECTION004138000000000000000>the Condor manual</a>.
    "
),
array("February 22, 2006",
    "BOINC announces its
    <a href=mac_intel.php>support for the Macintosh/Intel platform</a>.
    "
),
array("February 19, 2006",
    "<a href=http://boinccast.podhost.de/>BOINCcast</a>
    is the first German Podcast about BOINC.
    Weekly episodes of 5 minutes length will explain Distributed Computing
    and the Goals of BOINC to the German public,
    and will present and explain the projects that use BOINC.
    "
),
array("February 15, 2006",
    "View <a href=http://news.bbc.co.uk/nolavconsole/ukfs_news/hi/newsid_4710000/newsid_4713000/bb_rm_4713004.stm>a video clip</a>
    about the BBC Climate Change Experiment.
    "
),
array("February 14, 2006",
    "BOINC and Climateprediction.net have joined forces with the BBC
    to launch a new experiment -- a full simulation of climate change
    from 1920 to 2080.
    The experiment is described on
    a BBC television documentary <b>Meltdown</b>
    (BBC-4, February 20th, for UK BOINCers).
    Simplified client software is available
    at <a href=http://bbc.co.uk/climatechange>bbc.co.uk/climatechange</a>.
    Experienced BOINCers can attach to http://bbc.cpdn.org
    (check out the new graphics!).
    Be warned that a 160-year climate simulation is a long workunit even
    by Climateprediction.net's extravagant standards.
    But if you have a fast machine and are prepared to give
    us first call on your CPU, just for the next couple of months,
    then you could see your results in a second BBC television programme
    scheduled for May.
    "
),
array("February 8, 2006",
    "The <a href=http://szdg.lpds.sztaki.hu/szdg/>SZTAKI Desktop Grid</a>
    is now in production.
    The project, based at the MTA-SZTAKI Laboratory of Parallel
    and Distributed Systems in Budapest, Hungary, is attempting
    to find all the generalized binary number systems
    (bases are matrices and digits are vectors) up to dimension 11."
),
array("February 6, 2006",
    "The <a href=http://boinc.bio.wzw.tum.de/boincsimap/>Similarity
    Matrix of Proteins (SIMAP)</a> project is now in production.
    SIMAP, based at the Technical University of Munich,
    uses volunteer computers to calculate similarities between proteins.
    It provides a public database of the resulting data,
    which plays a key role in many bioinformatics research projects.
    SIMAP is the first German BOINC-based project."
),
array("December 15, 2005",
    "A <a href=http://www.nature.com/news/2005/051212/full/051212-10.html>story
    about SETI@home's transition to BOINC</a> appears in the Nature web site."
),
array("December 12, 2005",
    "A new paper, <a href=http://boinc.berkeley.edu/boinc_papers/internet/paper.pdf>The Computational and Storage Potential of Volunteer Computing</a>,
    explores the limits of BOINC-based projects."
),
array("December 9, 2005",
    "BOINC has a job opening for an experienced programmer
    (C++/Python/PHP/SQL/HTML).
    For more information go to
    <a href=http://jobs.berkeley.edu/> http://jobs.berkeley.edu/</a>.
    The job is number 003496, and is listed under Information Technology."
),
array("November 29, 2005",
    "We have created a new email list,
    <a href=http://www.ssl.berkeley.edu/mailman/listinfo/boinc_announce>boinc_announce@ssl.berkeley.edu</a>,
    for announcements of new versions of BOINC client software."
),
array("November 27, 2005",
     "Check out <a href=https://uimon.cern.ch/twiki/pub/LHCAtHome/LinksAndDocs/boincciemat06.pdf>A BOINC seminar by Juan Antonio Lopez Perez of CERN</a>,
     presented at CIEMAT in Madrid, November 2005.
     Also available in a
     <a href=https://uimon.cern.ch/twiki/pub/LHCAtHome/LinksAndDocs/boincciematprint06.pdf>print version</a>."
),
array("November 15, 2005",
    "<a href=stats.php>Aggregate credit data</a>
    (user and host credit data summed over all BOINC projects)
    is now available in XML format.
    This data can be used for applications
    (like the 'Featured participant' above)
    that reflect overall contribution to BOINC project.
    "
),
array("November 1, 2005",
    "IBM's <a href=http://www.worldcommunitygrid.org/>World Community Grid</a>
    has launched a BOINC-based project (currenly Linux only)."
),
array("October 28, 2005",
    "David Anderson talks about BOINC and volunteer computing
    in a <a href=http://www.enterpriseleadership.org/listen/podcast-anderson>podcast at www.enterpriseleadership.org</a>."
),
array("October 20, 2005",
    "Version 5.2.2 of the BOINC client software has been released.
    It includes a simpler registration procedure,
    security enhancements, and numerous other improvements."
),
array("September 25, 2005",
    "<a href=http://boinc.bakerlab.org/rosetta/>Rosetta@home<a>,
    a BOINC-based project at the University of Washington,
    has launched and is seeking participants.
    Its goal is \"... to develop methods that accurately
    predict and design protein structures
    and complexes, an endeavor that may ultimately help researchers
    develop cures for human diseases.\""
),
array("September 23, 2005",
    "<a href=server_perf.pdf>High-Performance Task Distribution for Volunteer Computing</a>, a paper about BOINC server performance,
    will appear in the e-Science 2005 conference in December."
),
array("September 6, 2005",
    "<a href=http://www.theinstitute.ieee.org/portal/site/tionline/menuitem.130a3558587d56e8fb2275875bac26c8/index.jsp?&pName=institute_level1_article&TheCat=2201&article=tionline/legacy/inst2005/sep05/9w.fgravity.xml&>Searching for Gravity @ Home</a>, an article about Einstein@home and BOINC,
    appears in the September 2005 issue of IEEE's <i>The Institute</i>."
),
array("August 29, 2005",
    "<a href=http://www.acmqueue.com/modules.php?name=Content&pa=showpage&pid=313>A conversation with David Anderson</a> in ACM Queue Magazine."
),
array("August 14, 2005",
    "We are <a href=new_setup.php>redesigning BOINC</a> to use
    a user-supplied identifier and password
    instead of a system-supplied random key
    for identifying an account.
    Comments on the design are welcome."
),
array("August 9, 2005",
    "BOINC is transitioning to use <a href=http://curl.haxx.se/>libcurl</a>
    for HTTP operations.
    This will allow BOINC to use HTTPS (secure HTTP)
    for scheduler requests and file transfers."
),
array("August 3, 2005",
    "Non-open-source code (RSAEuro and GLUT) has been removed from BOINC.
    OpenSSL's crypto library is used for encryption."
),

array("July 25, 2005", 
    "A group of students from Cornell have written
    <a href=distributing_science_final.pdf>Distributing Science</a>,
    a very nice article about BOINC
    and some of the projects using it."
),
array("July 24, 2005",
    "<a href=http://www.fatbat.dk/thesis/>A paper by Jakob Pedersen and Christian S&#248;ttrup</a>
    discusses the interoperation of the Grid and BOINC."
),

array("July 11-12, 2005",
    "The <a href=cern_workshop.php>First Pangalactic BOINC Workshop</a>
    was held at CERN,
    bringing together people from ClimatePrediction.net,
    Einstein@home, CERN, and BOINC.
    "
),
array("June 25, 2005",
    "BOINC <a href=stats_sites.php>statistics</a> sites continue to evolve.
    Check out <a href=http://home.btconnect.com/Gabys_Bazar/hwupgrade.html>Every Earthly Hour</a>, developed by Hydnum Repandum"
),
array("June 24, 2005",
    "We have added
    <a href=http://boinc.berkeley.edu/api.php#credit>new API calls</a>
    that allow applications to do their own CPU benchmarking,
    or directly report their floating-point operation count.
    This will give more accurate credit numbers for
    applications that are optimized for specific architectures
    or that use non-CPU computing resources such as GPUs."
),
array("June 24, 2005",
    "We've added two mechanisms that give better estimates
    of result completion time
    (and thus better scheduling and fewer missed deadlines):
    1) we track the 'CPU efficiency': the average fraction
    of CPU time that BOINC apps receive while they're running
    (this can be less than one on systems that run
    compute-intensive tasks other than BOINC);
    2) we dynamically maintain a per-project upper bound on the
    ratio of actual CPU time to predicted CPU time."
),
array("June 24, 2005",
    "We've improved and simplified the CPU scheduling and work-fetch policies,
    using a detailed simulation of BOINC's weighted round-robin scheduling.
    When the simulator predicts that a deadline will be missed,
    the client switches to earliest-deadline-first scheduling.
    When the simulator predicts that fetching additional work
    will cause a deadline to be missed, it suspends work fetch."
),
array("June 24, 2005",
    "<a href=trac/wiki/AccountManagers>Account management system</a>
    are web sites that let participants sign up for
    multiple projects with just a few clicks (and no account keys).
    The BOINC manager (development version) now lets you
    select, change, or get updated account info from an account manager."
),
array("June 24, 2005",
    "BOINC now works in Windows 'service' mode on computers
    with dialup connections and the 'confirm before connect' preference set.
    The connection confirmation and setup process has been
    moved to the BOINC manager, which (unlike a service)
    is able to do GUI activities."
),

array("June 16, 2005",
    "Climateprediction.net is featured in
    <a href=http://www.iee.org/oncomms/sector/PN_Article.cfm?objectID=3D100A5C-BC75-D279-D8D15A49EC4131B4>an article</a>
    in the journal of the Institute of Electrical Engineers."
),
array("June 3, 2005",
    "Two Wiki-based BOINC informational sites have been launched recently:
    <a href=http://www.boinc-wiki.info/>The Unofficial BOINC Wiki</a>
    (in English) and
    <a href=http://faq.boinc.de/>Deutsche BOINC FAQ</a> (in German).
    Because these sites are Wikis,
    participants can add and modify content."
),
array("May 31, 2005",
    "BOINC is featured in <a href=http://sciencereview.berkeley.edu:7066/pdf/5.1/briefs_pt3.pdf>The Berkeley Science Review</a>."
),
array("May 14, 2005",
    "Eric Myers and Charlie Fenton have written
    excellent documents on
    <a href=compile.php>how to compile BOINC and BOINC applications
    on Windows, Linux, and Mac OS X</a>."
),
array("May 11, 2005",
    "BOINC and BOINC-based projects are discussed in
    the article 'Grassroots Computing'
    in the May 6 2005 issue of
    <a href=http://www.sciencemag.org/sciext/computers/>Science magazine</a>."
),
array("May 10, 2005",
    "LHC@home is a BOINC-based project being used to
    simulate the orbits of particles in CERN's Large Hadron Collider (LHC).
    Read about it in the
    <a href=http://bulletin.cern.ch/eng/articles.php?bullno=13/2005&base=art#Article1>CERN Bulletin</a>.
    "
),
array("May 10, 2005",
    "As the number of BOINC-based projects has increased,
    a problem has emerged - if a computer is attached to lots of projects,
    it may have trouble finishing work in time.
    We are revising the BOINC client's <a href=sched.php>CPU scheduling
    and work-fetch policies</a> to address this issue."
),
array("May 10, 2005",
    "Many BOINC applications have interactive graphics
    (e.g. you can zoom in/out using the mouse).
    For apps that use the latest BOINC API, you can interact
    even when in screensaver mode - just hold down the control key."
),
array("May 10, 2005",
    "We finally have an installer and GUI for Mac OS X!
    It is available as a development version,
    and will become the standard version soon."
),
array("April 11, 2005",
    "Volunteers have ported SETI@home and BOINC to
    <a href=http://boinc.berkeley.edu/trac/wiki/DownloadOther>a variety of platforms</a>,
    including Solaris/x86-64, Linux/x86-64, Linux/PPC, HP-UX, and FreeBSD."
),

array(
    "March 8, 2005",
    "We released the BOINC Menubar, a user-friendly client software
    version for Macintosh OS X.
    It can be installed and run through a GUI interface -
    no Unix commands.
    We also released the Windows installer announced in
    the January 1 2005 news item.
    Both are available on the <a href=download.php>Download</a> page."
),
array(
    "February 19, 2005",
    "The <a href=http://einstein.phys.uwm.edu/>Einstein@home</a>
    project was officially launched this morning.
    BOINC users are encouraged to participate in this project,
    which searches for spinning neutron stars (also called pulsars)
    using data from the LIGO and GEO gravitational wave detectors.
    "
),
array(
    "February 17, 2005",
    "We've added a <a href=trac/wiki/TranslateIntro>framework for web-site translations</a>
    (both BOINC-supplied and project-specific parts).
    We are adding support for
    <a href=trac/wiki/AccountManagers>account management systems</a>
    that simplify participation in multiple projects.
    Security enhancement: all application files are digitally signed.
    "
),
array(
    "January 20, 2005",
    "BOINC source code is now distributed under the
    Lesser GNU Public License (LPGL)."
),
array(
    "January 19, 2005",
    "BOINC-based projects projects now have
    80,721 participants in 188 countries.
    Based on <a href=http://boinc.berkeley.edu/trac/wiki/CreditSystem>current credit statistics</a>,
    together they supply 106 TeraFLOPS of computing power -
    far more than any conventional supercomputer."
),
array(
    "January 18, 2005",
    "BOINC's message board system supports moderation."
),
array(
    "January 10, 2005",
    "With help from the Einstein@home group, we have refined BOINC's
    <a href=sched_locality.php>locality scheduling</a> mechanism,
    It can now interact with project-specific programs
    that generate work on demand,
    and that maintain a 'working set' of data files
    for which work is distributed."
),
array(
    "January 1, 2005",
    "The Windows version of BOINC can now be configured
    to run when a particular user is logged in,
    to run when any user is logged in,
    or run all the time (as a service)
    even when no users are logged in."
),

array("December 10, 2004",
    "With considerable help from the Einstein@home group,
    we have application graphics working on all platforms, including Linux.
    To handle hosts without graphics libraries,
    we have developed a <a href=graphics.php>new architecture</a> in which
    graphics code resides in a dynamically loaded library."
),
array("December 6, 2004",
    "Added prioritization to work distribution."
),
array("December 3, 2004",
    "We have created a new email list,
    <a href=http://www.ssl.berkeley.edu/mailman/listinfo/boinc_cvs>boinc_cvs@ssl.berkeley.edu</a>.
    A summary of each CVS checkin to the BOINC source tree
    will be posted to this list."
),

array(
    "December 2, 2004",
    "A technical paper about BOINC is
    <a href=grid_paper_04.pdf>here</a>.
    This paper appeared in the
    5th IEEE/ACM International Workshop on Grid Computing,
    November 8, 2004, Pittsburgh, USA."
),
array(
    "November 21, 2004",
    "We have developed a GUI for the core client.
    It's similar to the old Windows GUI but is implemented
    using <a href=http://www.wxwidgets.org/>wxWidgets</a>
    so it runs on all platforms.
    It offers new features such as the ability to
    suspend/resume projects and results,
    and project-specific web links.
    It uses a socket-based GUI RPC mechanism,
    which makes it possible to develop other GUIs,
    including ones that control many hosts.
    "
),
array(
    "November 21, 2004",
    "A new utility, db_purge, allows projects to
    flush old entries from the result and workunit tables,
    so that these tables have a bounded size."
),
array(
    "November 21, 2004",
    "We have developed a new Windows installer
    that lets you run BOINC as a service,
    and that is compatible with the Microsoft MSI framework."
),
array(
    "November 21, 2004",
    "The application graphics framework now works on
    all platforms, including Mac OS X."
),
array(
    "November 21, 2004",
    "The message-board system now supports self-moderation
    (i.e., 'ignore lists')."
),
array(
    "November 21, 2004",
    "BOINC servers can now use read-only database replicas
    for increased throughput."
),
array(
    "September 21, 2004",
    "XML Schemas for the statistics data exported by BOINC projects
    is <a href=BOINCSchemas/>here</a>,
    and graphical representations are
    <a href=BOINCSchemas/documentation/>here</a>."
),
array(
    "September 14, 2004",
    "We have created an email list, boinc_opt@ssl.berkeley.edu,
    for people interested in porting and optimizing BOINC applications.
    Sign up <a href=http://www.ssl.berkeley.edu/mailman/listinfo/boinc_opt>here</a>."
),
array(
    "September 11, 2004",
    "We are working on a new type of work distribution, called
    <a href=sched_locality.php>Locality scheduling</a>,
    that sends work to hosts that already have the needed files."
),
array(
    "September 6, 2004",
    "The <a href=http://lattice.umiacs.umd.edu/>Lattice</a> project
    from the University of Maryland
    is developing a Grid system that integrates Globus,
    BOINC, and several other software components."
),
array(
    "September 1, 2004",
    "The new project LHC@home announces its first beta test,
    initially restricted to 1000 users.
    Please sign up at <a href=http://lhcathome.cern.ch>lhcathome.cern.ch</a>."
),
array(
    "August 26, 2004",
    "The <a href=http://climateprediction.net/>Climateprediction.net</a>
    project is now open to the public."
),
array(
    "August 6, 2004",
    "Users can choose whether applications should
    quit or suspend when they're not executing."
),
array(
    "August 5, 2004",
    "The core client now checks whether disk usage exceeds
    user-specified limits, and if so it deletes projects files
    in a way that respects project resource shares."
),
array(
    "August 5, 2004",
    "Large BOINC projects (like SETI@home) were getting
    on the order of a million files in upload/download directories.
    This caused OS performance problems.
    We fixed this by providing a two-level directory
    hierarchy for upload/download directories."
),
array(
    "August 3, 2004",
    "The Climateprediction.net project recently held an
    <a href=http://www.climateprediction.net/project/openday.php>Open Day</a>,
    describing its status and its plans to use BOINC.
    "
),
array(
    "July 9, 2004",
    "We made the core/app interface more flexible and general,
    providing better support for applications that consist
    of separate controller, worker, and graphics programs.
    We also added mechanisms that prevent
    multiple applications from running in the same slot,
    and that cause applications to exit if the core client dies.
    "
),
array(
    "July 9, 2004",
    "We changed the SQL queries used by the performance-critical
    server components, such as the transitioner and feeder,
    to boost maximum server throughput."
),
array(
    "July 9, 2004",
    "The core client now does preemptive scheduling of results.
    It time-slices between results,
    maintaining the approximate project resource shares.
    The work-fetch policy has also been modified;
    a single 'connection frequency' parameter replaces the
    min/max buffer parameter,
    and the policy matches the requirements of the CPU-scheduling policy."
),
array(
    "July 9, 2004",
    "We have added a mechanism that allows projects to
    upload and download 'persistent files'.
    This is the first step to using participant hosts for storage
    as well as computation, possibly creating
    the world's largest storage server."
),
array(
    "June 20, 2004",
    "The <a href=db_dump.php>statistics export mechanism</a> has been redesigned
    to give projects more control over what they export;
    e.g. they can shift the burden of sorting to statistics web sites."
),
array(
    "June 16, 2004",
    "New features: support for multi-program applications.
    Daily result quota per host.
    Applications can supply a static graphic
    (for screensaver) without writing code.
    Improved support for FORTRAN.
    Support for GUI RPCs in Windows client.
    Option for allowing GUI RPCs from non-local hosts.
    Check for keyboard/mouse input in Unix.
    Support for name/password authentication for HTTP proxies."
),

array("May 31, 2004",
    "BOINC news is available as an RSS feed;
    see Community and Resources."
),

array(
    "May 19, 2004",
    "CPU benchmarking (and credit) are now based on
    the Dhrystone and Whetstone benchmarks.
    Memory bandwidth is no longer measured."
),

array("May 18, 2004",
"Source code is now available
<a href=source_code.php>directly via CVS</a>.
Improved Unix signal handling.
Support app versions, workunits and results with lots of files
(changed XML fields from 4KB to 64KB).
Added
<a href=homogeneous_redundancy.php>homogeneous redundancy</a> mechanism.
"),

array("May 2, 2004",
"General preferences are now propagated from client to server,
but only to accounts with the same email address
as where the preferences originated.
"),

array("April 20, 2004",
"Added <a href=cpid.php>cross-project identification</a> system.
Added support for caching of PHP web pages,
and restored leaderboard pages.
"),

array("April 12, 2004",
"Recent fixes and features:
<a href=http://boinc.berkeley.edu/trickle.php>trickle messages</a>
for long-running work units;
benchmarking for hyperthreaded CPUs;
don't propagate preferences from hosts to projects;
check for file existence before running apps;
SOCKS proxy support;
separate suspend/resume for network activity;
fix race conditions in server;
add file compression code.
See checkin_notes for details.
"),

array("March 16, 2004",
"An unauthorized
<a href=calvin-hobbes-boinc.jpg>BOINC graphic</a>.
"),

array("February 11, 2004",
"BOINC is being used at the Scripps Research Institute
to run a distributed version of CHARMM
(a program for macromolecular simulations).
"),

array("February 1, 2004",
"BOINC now has an
<a href=http://boinc.berkeley/edu/trac/wiki/AnonymousPlatform>anonymous platform mechanism</a>
which 1) allows computers of any type to participate
in a BOINC project, and 2) allows participants to
run only software they have compiled themselves,
should they so desire.

"),

array("January 22, 2004",
"The BOINC core client now provides
<a href=gui_rpc.php>a set of RPCs allowing separate GUIs to be developed</a>.
"),

array("November 26, 2003",
"The CVS repository of BOINC code (including web pages) is now visible through
<a href=http://boinc.berkeley.edu/cgi-bin/cvsweb.cgi/>a web-based interface</a>.
This may be useful for people maintaining web-site translations.
"),

array("November 26, 2003",
"A <a href=http://boinc.berkeley.edu/madrid.html>paper
about the goals of BOINC</a> was presented at a recent conference.
"),

array("November 25, 2003",
"The beta test project is accepting new users.
CPU time measurement accuracy improved.
Scheduler respects disk usage limits.
Web site can issue cookies.
"),

array("November 5, 2003",
"The graphics of running application are updated whenever
preferences are changed.
The scheduler now issues only as many results as will fit in
the allotted amount of disk space.

"),

array("October 30, 2003",
"New minor versions of the core client and beta-test apps have been released.
XML statistics data for the beta test
<a href=http://setiboinc.ssl.berkeley.edu/ap/stats.php>is available</a>;
it's intended for graphical or tabular representation.
"),

array("October 18, 2003",
"A SETI@home application has been added to the beta test.
The scheduling server detect results that can't be sent
to any hosts, and flags them.
HTTP 404 errors on downloads are treated as unrecoverable.
Graphics can be limited by frame rate or percent of CPU.
Don't send two results from the same workunit to a single user.
Added JPEG support to application graphics.
Added \"confirm before accept executable\" mechanism.

"),

array("September 11, 2003",
"BOINC is discussed in
<a href=http://www.nytimes.com/2003/09/11/technology/circuits/11dist.html>
an article by Joan Oleck in the New York TImes</a>.
"),


array("September 4, 2003",
"We've released BOINC version 2.0.
All BOINC components must be upgraded to major version 2.
We've upgraded the <a
href=http://maggie.ssl.Berkeley.edu/ap/>Astropulse</a> server to 2.01 and
released <a href=http://setiboinc.ssl.Berkeley.edu/ap/download.php>BOINC core
client 2.01</a>.
This was due to an architecture and protocol change in
specifying resource estimates and limits.
"),

array("September 1, 2003",
"BOINC server tools are now Python-based.  A <a href=python.php>database
back-end API</a> allows quick development of data-manipulation utilities.
"),

array("August 15, 2003",
"We rewrote parts of the scheduling server architecture to make operations
more flexible and efficient.
The <code>timeout_check</code>
daemon has been replaced by a more general <code>transitioner</code> daemon.
"),

array("July 25, 2003",
"We've added two new web-site features for BOINC projects:
user profiles and message boards.
These are visible on the <a href=http://maggie.ssl.berkeley.edu/ap/>beta-test web site</a>.
"),

array("July 23, 2003",
"The <a href=source/>BOINC source code</a> is available again,
under <a href=legal.html>a new public license</a>.
Version 1.05 incorporates bug fixes and new features,
including the ability to add your own graphics to the screensaver.
The beta test has been resumed, and the scheduling server and
database have been moved to a new machine.
"),

array("June 10, 2003",
"<a href=http://boinc.berkeley.edu/db_dump.php>XML based statistics</a> for
the Astropulse beta test are
<a href=http://setiboinc.ssl.berkeley.edu/ap/stats/>available</a>.
"),

array("May 30, 2003",
"No big news to report,
but thanks to the beta test we've fixed a number of bugs,
involving runaway applications, too-large output files,
screensaver behavior, and mechanisms for
quitting and resetting projects.
"),

array("April 29, 2003",
"We have created a second project, allowing beta testers to
experiment with dividing their resources between multiple projects.
"),

array("April 23, 2003",
"We have resumed the BOINC beta test.
"),

array("April 9, 2003",
"Due to a legal issue,
we are suspending the BOINC beta test,
and we have requested that BOINC source code
no longer be available at Sourceforge.net.
We hope to resolve this issue soon.
"),

array("March 31, 2003",
"We are preparing a BOINC-based version of SETI@home.
See a <a href=setiathome.jpg>preview of the graphics</a>.
"),

array("March 25, 2003",
"<a href=http://www.boinc.dk/index.php?page=download_languages>Non-English
language.ini files</a> are available.
Preferences include time-of-day restrictions.
Core client and applications communicate via shared memory and signals
rather than files, reducing disk traffic.
"),

array("March 19, 2003",
"New account parameters and preferences: URL, limit number of processors,
frequency of writes to disk, whether to show your computers on the web.
"),

array("March 4, 2003",
"Participants can have separate preferences
(such as network and disk usage limits)
for computers at home, work, and school.
"),

array("February 25, 2003",
"Participants can limit their upstream and downstream network bandwidth.
"),

array("February 22, 2003",
"Participants can control the parameters (color, transparency,
timing) of the Astropulse graphics.
"),

array("February 19, 2003",
"New feature: secure, verified email address update.
"),

array("January 29, 2003",
"A <a href=http://setiathome.berkeley.edu/~eheien/ap_ss.jpg>screenshot</a> of the
BOINC client running AstroPulse, our first test application.
"),

array("December 10, 2002",
"We have started a beta test of BOINC using
the Astropulse application.
Many bugs have been found and fixed.
"),

array("August 24, 2002",
"BOINC is under development.
The basic features are working on UNIX platforms.
We plan to release the first public application of BOINC later this year.
")
);

?>
